library("gplots")

rootPath <- "/"

path <- paste(rootPath, "2ndYear/my_papers/bica/codes/", sep="")
pathSource <- paste(path, "Rcodes/", sep="")

modelResultsDir <- "results/blicket/"

resultPath <- paste(path, modelResultsDir, sep="")

loadResultFile <- function(filename){
	return(read.table(paste(resultPath, filename, sep=""), stringsAsFactors=FALSE, header=TRUE))
}

blockA <- "BLOCKA"
blockB <- "BLOCKB"
blockC <- "BLOCKC"

blicket <- "BLICKET"

doExper2_2011 <- function(){
	initPhase <- "T10"
	abPhase <- "T11"
	acPhase <- "T12"

	groupDF <- loadResultFile("exper2_2011.txt")


	initA <- nrow(subset(groupDF, groupDF$Timestamp == initPhase & groupDF$Block == blockA & groupDF$BlockType == blicket))/
				nrow(subset(groupDF, groupDF$Timestamp == initPhase & groupDF$Block == blockA))
	abA <- nrow(subset(groupDF, groupDF$Timestamp == abPhase & groupDF$Block == blockA & groupDF$BlockType == blicket))/
				nrow(subset(groupDF, groupDF$Timestamp == abPhase & groupDF$Block == blockA))
	acA <- nrow(subset(groupDF, groupDF$Timestamp == acPhase & groupDF$Block == blockA & groupDF$BlockType == blicket))/
				nrow(subset(groupDF, groupDF$Timestamp == acPhase & groupDF$Block == blockA))

	initB <- nrow(subset(groupDF, groupDF$Timestamp == initPhase & groupDF$Block == blockB & groupDF$BlockType == blicket))/
					nrow(subset(groupDF, groupDF$Timestamp == initPhase & groupDF$Block == blockB))
	abB <- nrow(subset(groupDF, groupDF$Timestamp == abPhase & groupDF$Block == blockB & groupDF$BlockType == blicket))/
					nrow(subset(groupDF, groupDF$Timestamp == abPhase & groupDF$Block == blockB))
	acB <- nrow(subset(groupDF, groupDF$Timestamp == acPhase & groupDF$Block == blockB & groupDF$BlockType == blicket))/
					nrow(subset(groupDF, groupDF$Timestamp == acPhase & groupDF$Block == blockB))

	initC <- nrow(subset(groupDF, groupDF$Timestamp == initPhase & groupDF$Block == blockC & groupDF$BlockType == blicket))/
					nrow(subset(groupDF, groupDF$Timestamp == initPhase & groupDF$Block == blockC))
	abC <- nrow(subset(groupDF, groupDF$Timestamp == abPhase & groupDF$Block == blockC & groupDF$BlockType == blicket))/
					nrow(subset(groupDF, groupDF$Timestamp == abPhase & groupDF$Block == blockC))
	acC <- nrow(subset(groupDF, groupDF$Timestamp == acPhase & groupDF$Block == blockC & groupDF$BlockType == blicket))/
					nrow(subset(groupDF, groupDF$Timestamp == acPhase & groupDF$Block == blockC))


	print(c(initA, abA, acA))
	print(c(initB, abB, acB))
	print(c(initC, abC, acC))

	plot(x=c(1:3), y=c(initA, abA, acA), ylim=c(0, 1), type="b", col="blue")
	lines(x=c(1:3), y=c(initB, abB, acB), type="b", col="black")
	lines(x=c(1:3), y=c(initC, abC, acC), type="b", col="red")
	abline(a=0.5, b=0, col="red")
}

doExper1_2011 <- function(){
	op <- par(mfrow=c(5,1), mar=c(3, 3, 0.5, 0.5))

	initPhase <- "T10"
	abPhase <- "T11"
	aPhase <- "T12"

	resultDF <- loadResultFile("exper1_2011.txt")

	groupVect <- sort(unique(resultDF$Group))

	groupNames <- c("1/6", "1/3", "1/2", "2/3", "5/6")

	print(groupVect)

	drawLegendFlag <- TRUE

	for(currGroupIndex in 1:length(groupVect)){
		currGroupID <- groupVect[currGroupIndex]

		groupDF <- subset(resultDF, resultDF$Group == currGroupID)
		experCount <- unique(groupDF$ExperID)

		initA <- nrow(subset(groupDF, groupDF$Timestamp == initPhase & groupDF$Block == blockA & groupDF$BlockType == blicket))/
					nrow(subset(groupDF, groupDF$Timestamp == initPhase & groupDF$Block == blockA))
		abA <- nrow(subset(groupDF, groupDF$Timestamp == abPhase & groupDF$Block == blockA & groupDF$BlockType == blicket))/
					nrow(subset(groupDF, groupDF$Timestamp == abPhase & groupDF$Block == blockA))
		aA <- nrow(subset(groupDF, groupDF$Timestamp == aPhase & groupDF$Block == blockA & groupDF$BlockType == blicket))/
					nrow(subset(groupDF, groupDF$Timestamp == aPhase & groupDF$Block == blockA))

		initB <- nrow(subset(groupDF, groupDF$Timestamp == initPhase & groupDF$Block == blockB & groupDF$BlockType == blicket))/
					nrow(subset(groupDF, groupDF$Timestamp == initPhase & groupDF$Block == blockB))
		abB <- nrow(subset(groupDF, groupDF$Timestamp == abPhase & groupDF$Block == blockB & groupDF$BlockType == blicket))/
					nrow(subset(groupDF, groupDF$Timestamp == abPhase & groupDF$Block == blockB))
		aB <- nrow(subset(groupDF, groupDF$Timestamp == aPhase & groupDF$Block == blockB & groupDF$BlockType == blicket))/
					nrow(subset(groupDF, groupDF$Timestamp == aPhase & groupDF$Block == blockB))

		print(c(initA, abA, aA))
		print(c(initB, abB, aB))

		plot(x=c(1:3), y=c(initA, abA, aA), ylim=c(0, 1), type="b", col="blue", axes=FALSE
			, ylab="Proportion", main=paste("ACT-R model (", groupNames[currGroupIndex], ")", sep="")
			, pch=0
		)
		axis(1, at=c(1:3), labels=c("Initial", "After AB", "After A"))
		axis(2, at=c(0.0, 0.5, 1.0), labels=c(0, 0.5, 1))
		lines(x=c(1:3), y=c(initB, abB, aB), type="b", col="black", pch=22, bg="gray")
		#abline(a=0.5, b=0, col="red")

		if(drawLegendFlag){
			legend(x=1, y=1, lty=1, col=c("blue", "black")
					, bg=c("white", "black")
					, pch=c(0, 22)
					, legend=c("A", "B")
					)
			drawLegendFlag <- FALSE
		}
	}

	par(op)
}


getExp2_2004_blicket_count <- function(dataDF){
	experIDvect <- sort(unique(dataDF$ExperID))

	aCountVect <- numeric()
	bCountVect <- numeric()

	for(currExperID in 1:length(experIDvect)){
		currExperID <- experIDvect[currExperID]

		aBlicketCount <- nrow(subset(dataDF, ExperID == currExperID & Block == blockA & BlockType == blicket))
		bBlicketCount <- nrow(subset(dataDF, ExperID == currExperID & Block == blockB & BlockType == blicket))

		aCountVect <- c(aCountVect, aBlicketCount)
		bCountVect <- c(bCountVect, bBlicketCount)
	}

	return(list(aCountVect, bCountVect))
}

doExper2_2004 <- function(){
	screenID <- "SCREENING"
	blockID <- "BLOCKING"
	assocID <- "ASSOCIATION"

	op <- par(mfrow=c(2,1))

	############################################################################################
	###### START: plotting human data

	#		                     Indirect screen-off             Backward blocking                 Association
	#		                        A            B                A             B                A             B
	#		4-year-olds (16)    0.00 (0.00)  1.88 (0.17)      2.00 (0.00)  0.69 (0.44)       1.88 (0.17)   2.00 (0.00)

	humanPropMeanMatrix <- matrix(c(c(0.0, 1.88), c(2.0, 0.69), c(1.88, 2.0)), nrow = 2, ncol=3, byrow=FALSE
							, dimnames = list(c("Block A", "Block B"), c("Screening-off", "Blocking", "Association")))
	humanPropSEMatrix <- matrix(c(c(0.0, 0.17), c(0.0, 0.44), c(0.17, 0.0)), nrow = 2, ncol=3, byrow=FALSE)

	barplot2(height=humanPropMeanMatrix
			, plot.ci=TRUE # set to TRUE if you want to plot the standard errors
			, ci.l=humanPropMeanMatrix-humanPropSEMatrix
			, ci.u=humanPropMeanMatrix+humanPropSEMatrix
			, beside=TRUE  # use this if you have more than one condition and you want to group bars
			, ylim=c(0, 2) # scale of y axis: min is 0 and max is 25
			, main="Human data"
			#, ylab="Percentage Adult-like responses"
			#, xlab="Set A+ justifications"
			#, names.arg=c("All", "Only")
			, border=rep(c("blue", "black"), 2) # border colors; vector of four colors since dataDF has four means
			, col=rep(c("blue", "black"), 2) # fill colors; vector of four colors since dataDF has four means
			, density=10, angle=rep(c(45, 135), 2)
	)

	###### END: plotting human data
	############################################################################################


	############################################################################################
	###### START: plotting model data

	resultDF <- loadResultFile("exper2_2004.txt")

	screenGroup <- subset(resultDF, resultDF$Group == screenID)
	blockGroup <- subset(resultDF, resultDF$Group == blockID)
	assocGroup <- subset(resultDF, resultDF$Group == assocID)


	screenCountList <- getExp2_2004_blicket_count(screenGroup)
	blockCountList <- getExp2_2004_blicket_count(blockGroup)
	assocCountList <- getExp2_2004_blicket_count(assocGroup)


	screenProps <- c(mean(screenCountList[[1]]), mean(screenCountList[[2]]))
	blockProps <- c(mean(blockCountList[[1]]), mean(blockCountList[[2]]))
	assocProps <- c(mean(assocCountList[[1]]), mean(assocCountList[[2]]))

	print(screenProps)
	print(blockProps)
	print(assocProps)

	propMatrix <- matrix(c(screenProps, blockProps, assocProps), nrow = 2, ncol=3, byrow=FALSE
					, dimnames = list(c("Block A", "Block B"), c("Screening-off", "Blocking", "Association")))

	barplot2(height=propMatrix
			, plot.ci=FALSE # set to TRUE if you want to plot the standard errors
			, beside=TRUE  # use this if you have more than one condition and you want to group bars
			, ylim=c(0, 2) # scale of y axis: min is 0 and max is 25
			, main="Model fit"
			#, ylab="Percentage Adult-like responses"
			#, xlab="Set A+ justifications"
			#, names.arg=c("All", "Only")
			, border=rep(c("blue", "black"), 2) # border colors; vector of four colors since dataDF has four means
			, col=rep(c("blue", "black"), 2) # fill colors; vector of four colors since dataDF has four means
			, density=10, angle=rep(c(45, 135), 2)
	)

	###### END: plotting model data
	############################################################################################

}

getExp1_2001_blicket_count <- function(dataDF){
	experIDvect <- sort(unique(dataDF$ExperID))

	aCountVect <- numeric()
	bCountVect <- numeric()

	for(currExperID in 1:length(experIDvect)){
		currExperID <- experIDvect[currExperID]

		aBlicketCount <- nrow(subset(dataDF, ExperID == currExperID & Block == blockA & BlockType == blicket))
		bBlicketCount <- nrow(subset(dataDF, ExperID == currExperID & Block == blockB & BlockType == blicket))

		aCountVect <- c(aCountVect, aBlicketCount)
		bCountVect <- c(bCountVect, bBlicketCount)
	}

	return(list(aCountVect, bCountVect))
}

doExper1_2001 <- function(){
	ocID <- "OC"
	tcID <- "TC"

	op <- par(mfrow=c(3,1))

	############################################################################################
	###### START: plotting human data

	humanPropMean4Matrix <- matrix(c(c(1.81, 0.31), c(1.94, 1.56)), nrow = 2, ncol=2, byrow=FALSE
							, dimnames = list(c("Block A", "Block B"), c("One-cause", "Two-cause")))
	#humanPropSE4Matrix <- matrix(c(c(0.0, 0.0), c(0.0, 0.0)), nrow = 2, ncol=2, byrow=FALSE)

	barplot2(height=humanPropMean4Matrix
			, plot.ci=FALSE # set to TRUE if you want to plot the standard errors
			#, ci.l=humanPropMean4Matrix-humanPropSE4Matrix
			#, ci.u=humanPropMean4Matrix+humanPropSE4Matrix
			, beside=TRUE  # use this if you have more than one condition and you want to group bars
			, ylim=c(0, 2) # scale of y axis: min is 0 and max is 25
			, main="Human data (4 year olds)"
			#, ylab="Percentage Adult-like responses"
			#, xlab="Set A+ justifications"
			#, names.arg=c("All", "Only")
			, border=rep(c("blue", "black"), 2) # border colors; vector of four colors since dataDF has four means
			, col=rep(c("blue", "black"), 2) # fill colors; vector of four colors since dataDF has four means
			, density=10, angle=rep(c(45, 135), 2)
	)

	humanPropMean3Matrix <- matrix(c(c(2.00, 1.31), c(1.94, 1.69)), nrow = 2, ncol=2, byrow=FALSE
							, dimnames = list(c("Block A", "Block B"), c("One-cause", "Two-cause")))
	#humanPropSE3Matrix <- matrix(c(c(0.0, 0.0), c(0.0, 0.0)), nrow = 2, ncol=2, byrow=FALSE)

	barplot2(height=humanPropMean3Matrix
			, plot.ci=FALSE # set to TRUE if you want to plot the standard errors
			#, ci.l=humanPropMean3Matrix-humanPropSE3Matrix
			#, ci.u=humanPropMean3Matrix+humanPropSE3Matrix
			, beside=TRUE  # use this if you have more than one condition and you want to group bars
			, ylim=c(0, 2) # scale of y axis: min is 0 and max is 25
			, main="Human data (3 year olds)"
			#, ylab="Percentage Adult-like responses"
			#, xlab="Set A+ justifications"
			#, names.arg=c("All", "Only")
			, border=rep(c("blue", "black"), 2) # border colors; vector of four colors since dataDF has four means
			, col=rep(c("blue", "black"), 2) # fill colors; vector of four colors since dataDF has four means
			, density=10, angle=rep(c(45, 135), 2)
	)

	###### END: plotting human data
	############################################################################################


	resultDF <- loadResultFile("exper1_2001.txt")

	ocGroup <- subset(resultDF, resultDF$Group == ocID)
	tcGroup <- subset(resultDF, resultDF$Group == tcID)

	coCountList <- getExp1_2001_blicket_count(ocGroup)
	tsCountList <- getExp1_2001_blicket_count(tcGroup)

	ocProps <- c(mean(coCountList[[1]]), mean(coCountList[[2]]))
	tcProps <- c(mean(tsCountList[[1]]), mean(tsCountList[[2]]))

	print(ocProps)
	print(tcProps)

	propMatrix <- matrix(c(ocProps, tcProps), nrow = 2, ncol=2, byrow=FALSE
					, dimnames = list(c("Block A", "Block B"), c("One-cause", "Two-cause")))

	barplot2(height=propMatrix
			, plot.ci=FALSE # set to TRUE if you want to plot the standard errors
			, beside=TRUE  # use this if you have more than one condition and you want to group bars
			, ylim=c(0, 2) # scale of y axis: min is 0 and max is 25
			, main="Model fit"
			#, ylab="Percentage Adult-like responses"
			#, xlab="Set A+ justifications"
			#, names.arg=c("All", "Only")
			, border=rep(c("blue", "black"), 2) # border colors; vector of four colors since dataDF has four means
			, col=rep(c("blue", "black"), 2) # fill colors; vector of four colors since dataDF has four means
			, density=10, angle=rep(c(45, 135), 2)
	)
}

doTestAB <- function(){
	op <- par(mfrow=c(5,1), mar=c(0.5, 3, 0.5, 0.5))

	initPhase <- "T10"
	abPhase <- "T11"
	aPhase <- "T12"

	blockA <- "BLOCKA"
	blockB <- "BLOCKB"

	blicket <- "BLICKET"

	resultDF <- loadResultFile("testAB.txt")

	groupVect <- sort(unique(resultDF$Group))

	print(groupVect)

	for(currGroupIndex in 1:length(groupVect)){
		currGroupID <- groupVect[currGroupIndex]

		groupDF <- subset(resultDF, resultDF$Group == currGroupID)
		experCount <- unique(groupDF$ExperID)

		initA <- nrow(subset(groupDF, groupDF$Timestamp == initPhase & groupDF$Block == blockA & groupDF$BlockType == blicket))/
					nrow(subset(groupDF, groupDF$Timestamp == initPhase & groupDF$Block == blockA))
		abA <- nrow(subset(groupDF, groupDF$Timestamp == abPhase & groupDF$Block == blockA & groupDF$BlockType == blicket))/
					nrow(subset(groupDF, groupDF$Timestamp == abPhase & groupDF$Block == blockA))

		initB <- nrow(subset(groupDF, groupDF$Timestamp == initPhase & groupDF$Block == blockB & groupDF$BlockType == blicket))/
					nrow(subset(groupDF, groupDF$Timestamp == initPhase & groupDF$Block == blockB))
		abB <- nrow(subset(groupDF, groupDF$Timestamp == abPhase & groupDF$Block == blockB & groupDF$BlockType == blicket))/
					nrow(subset(groupDF, groupDF$Timestamp == abPhase & groupDF$Block == blockB))

		print(c(initA, abA))
		print(c(initB, abB))

		plot(x=c(1:2), y=c(initA, abA), ylim=c(0, 1), type="b", col="green")
		lines(x=c(1:2), y=c(initB, abB), type="b", col="black")
		abline(a=0.5, b=0, col="red")
	}

	par(op)
}

#doExper1_2001()

#doExper2_2004()

doExper1_2011()
#doExper2_2011()

#doTestAB()